SWDEV-470698 - fix formatting, add format check workflow (#657)
This commit is contained in:
committad av
GitHub
förälder
5840940caa
incheckning
f7338717ae
@@ -17,7 +17,7 @@ OUT OF OR INN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN
|
||||
THE SOFTWARE.
|
||||
*/
|
||||
#include <hip_test_common.hh>
|
||||
|
||||
|
||||
#include <stdio.h>
|
||||
#include <dlfcn.h>
|
||||
#include <vector>
|
||||
@@ -63,103 +63,94 @@ THE SOFTWARE.
|
||||
* - HIP_VERSION >= 5.6
|
||||
*/
|
||||
|
||||
void test_dynamicLoading(void* sym_hipGetDevice,
|
||||
void* sym_hipMalloc,
|
||||
void* sym_hipMemcpyHtoD,
|
||||
void* sym_hipMemcpyDtoH,
|
||||
void* sym_hipModuleLoad,
|
||||
void* sym_hipGetDeviceProperties,
|
||||
void* sym_hipModuleGetFunction,
|
||||
void* sym_hipModuleLaunchKernel){
|
||||
uint32_t *A_d, *C_d;
|
||||
uint32_t *A_h, *C_h;
|
||||
size_t N = 1000000;
|
||||
size_t Nbytes = N * sizeof(uint32_t);
|
||||
hipError_t (*dyn_hipGetDevice)(hipDevice_t*, int) = reinterpret_cast
|
||||
<hipError_t (*)(hipDevice_t*, int)>(sym_hipGetDevice);
|
||||
void test_dynamicLoading(void* sym_hipGetDevice, void* sym_hipMalloc, void* sym_hipMemcpyHtoD,
|
||||
void* sym_hipMemcpyDtoH, void* sym_hipModuleLoad,
|
||||
void* sym_hipGetDeviceProperties, void* sym_hipModuleGetFunction,
|
||||
void* sym_hipModuleLaunchKernel) {
|
||||
uint32_t *A_d, *C_d;
|
||||
uint32_t *A_h, *C_h;
|
||||
size_t N = 1000000;
|
||||
size_t Nbytes = N * sizeof(uint32_t);
|
||||
hipError_t (*dyn_hipGetDevice)(hipDevice_t*, int) =
|
||||
reinterpret_cast<hipError_t (*)(hipDevice_t*, int)>(sym_hipGetDevice);
|
||||
|
||||
hipError_t (*dyn_hipMalloc)(void**, uint32_t) = reinterpret_cast
|
||||
<hipError_t (*)(void**, uint32_t)>(sym_hipMalloc);
|
||||
hipError_t (*dyn_hipMalloc)(void**, uint32_t) =
|
||||
reinterpret_cast<hipError_t (*)(void**, uint32_t)>(sym_hipMalloc);
|
||||
|
||||
hipError_t (*dyn_hipMemcpyHtoD)(hipDeviceptr_t, void*, size_t) =
|
||||
reinterpret_cast<hipError_t (*)(hipDeviceptr_t, void*,
|
||||
size_t)>(sym_hipMemcpyHtoD);
|
||||
hipError_t (*dyn_hipMemcpyHtoD)(hipDeviceptr_t, void*, size_t) =
|
||||
reinterpret_cast<hipError_t (*)(hipDeviceptr_t, void*, size_t)>(sym_hipMemcpyHtoD);
|
||||
|
||||
hipError_t (*dyn_hipMemcpyDtoH)(void*, hipDeviceptr_t, size_t) =
|
||||
reinterpret_cast<hipError_t (*)(void*, hipDeviceptr_t,
|
||||
size_t)>(sym_hipMemcpyDtoH);
|
||||
hipError_t (*dyn_hipMemcpyDtoH)(void*, hipDeviceptr_t, size_t) =
|
||||
reinterpret_cast<hipError_t (*)(void*, hipDeviceptr_t, size_t)>(sym_hipMemcpyDtoH);
|
||||
|
||||
hipError_t (*dyn_hipModuleLoad)(hipModule_t*, const char*) = reinterpret_cast
|
||||
<hipError_t (*)(hipModule_t*, const char*)>(sym_hipModuleLoad);
|
||||
hipError_t (*dyn_hipModuleLoad)(hipModule_t*, const char*) =
|
||||
reinterpret_cast<hipError_t (*)(hipModule_t*, const char*)>(sym_hipModuleLoad);
|
||||
|
||||
hipError_t (*dyn_hipGetDeviceProperties)(hipDeviceProp_t*, int) =
|
||||
reinterpret_cast<hipError_t (*)(hipDeviceProp_t*, int)>
|
||||
(sym_hipGetDeviceProperties);
|
||||
hipError_t (*dyn_hipGetDeviceProperties)(hipDeviceProp_t*, int) =
|
||||
reinterpret_cast<hipError_t (*)(hipDeviceProp_t*, int)>(sym_hipGetDeviceProperties);
|
||||
|
||||
hipError_t (*dyn_hipModuleGetFunction)(hipFunction_t*, hipModule_t,
|
||||
const char*) = reinterpret_cast < hipError_t (*)(hipFunction_t*,
|
||||
hipModule_t, const char*)>(sym_hipModuleGetFunction);
|
||||
hipError_t (*dyn_hipModuleGetFunction)(hipFunction_t*, hipModule_t, const char*) =
|
||||
reinterpret_cast<hipError_t (*)(hipFunction_t*, hipModule_t, const char*)>(
|
||||
sym_hipModuleGetFunction);
|
||||
|
||||
hipError_t (*dyn_hipModuleLaunchKernel)(hipFunction_t, unsigned int,
|
||||
unsigned int, unsigned int, unsigned int, unsigned int,
|
||||
unsigned int, unsigned int, hipStream_t, void**, void**)
|
||||
= reinterpret_cast<hipError_t(*) (hipFunction_t,
|
||||
unsigned int, unsigned int, unsigned int, unsigned int,
|
||||
unsigned int, unsigned int, unsigned int, hipStream_t,
|
||||
void**, void**)>(sym_hipModuleLaunchKernel);
|
||||
hipError_t (*dyn_hipModuleLaunchKernel)(hipFunction_t, unsigned int, unsigned int, unsigned int,
|
||||
unsigned int, unsigned int, unsigned int, unsigned int,
|
||||
hipStream_t, void**, void**) =
|
||||
reinterpret_cast<hipError_t (*)(hipFunction_t, unsigned int, unsigned int, unsigned int,
|
||||
unsigned int, unsigned int, unsigned int, unsigned int,
|
||||
hipStream_t, void**, void**)>(sym_hipModuleLaunchKernel);
|
||||
|
||||
hipDevice_t device;
|
||||
HIPCHECK(dyn_hipGetDevice(&device, 0));
|
||||
hipDevice_t device;
|
||||
HIPCHECK(dyn_hipGetDevice(&device, 0));
|
||||
|
||||
hipDeviceProp_t props;
|
||||
HIPCHECK(dyn_hipGetDeviceProperties(&props, device));
|
||||
A_h = reinterpret_cast<uint32_t*>(malloc(Nbytes));
|
||||
REQUIRE(A_h != NULL);
|
||||
C_h = reinterpret_cast<uint32_t*>(malloc(Nbytes));
|
||||
REQUIRE(C_h != NULL);
|
||||
hipDeviceProp_t props;
|
||||
HIPCHECK(dyn_hipGetDeviceProperties(&props, device));
|
||||
A_h = reinterpret_cast<uint32_t*>(malloc(Nbytes));
|
||||
REQUIRE(A_h != NULL);
|
||||
C_h = reinterpret_cast<uint32_t*>(malloc(Nbytes));
|
||||
REQUIRE(C_h != NULL);
|
||||
|
||||
for (size_t i = 0; i < N; i++) {
|
||||
A_h[i] = i;
|
||||
}
|
||||
for (size_t i = 0; i < N; i++) {
|
||||
A_h[i] = i;
|
||||
}
|
||||
|
||||
HIPCHECK(dyn_hipMalloc(reinterpret_cast<void**>(&A_d), Nbytes));
|
||||
HIPCHECK(dyn_hipMalloc(reinterpret_cast<void**>(&C_d), Nbytes));
|
||||
HIPCHECK(dyn_hipMalloc(reinterpret_cast<void**>(&A_d), Nbytes));
|
||||
HIPCHECK(dyn_hipMalloc(reinterpret_cast<void**>(&C_d), Nbytes));
|
||||
|
||||
HIPCHECK(dyn_hipMemcpyHtoD((hipDeviceptr_t)(A_d), A_h, Nbytes));
|
||||
HIPCHECK(dyn_hipMemcpyHtoD((hipDeviceptr_t)(A_d), A_h, Nbytes));
|
||||
|
||||
struct {
|
||||
void* _Cd;
|
||||
void* _Ad;
|
||||
size_t _N;
|
||||
} args;
|
||||
args._Cd = reinterpret_cast<void**> (C_d);
|
||||
args._Ad = reinterpret_cast<void**> (A_d);
|
||||
args._N = static_cast<size_t> (N);
|
||||
size_t size = sizeof(args);
|
||||
struct {
|
||||
void* _Cd;
|
||||
void* _Ad;
|
||||
size_t _N;
|
||||
} args;
|
||||
args._Cd = reinterpret_cast<void**>(C_d);
|
||||
args._Ad = reinterpret_cast<void**>(A_d);
|
||||
args._N = static_cast<size_t>(N);
|
||||
size_t size = sizeof(args);
|
||||
|
||||
void* config[] = {HIP_LAUNCH_PARAM_BUFFER_POINTER, &args,
|
||||
HIP_LAUNCH_PARAM_BUFFER_SIZE, &size, HIP_LAUNCH_PARAM_END};
|
||||
void* config[] = {HIP_LAUNCH_PARAM_BUFFER_POINTER, &args, HIP_LAUNCH_PARAM_BUFFER_SIZE, &size,
|
||||
HIP_LAUNCH_PARAM_END};
|
||||
|
||||
hipModule_t Module;
|
||||
HIPCHECK(dyn_hipModuleLoad(&Module, fileName));
|
||||
hipModule_t Module;
|
||||
HIPCHECK(dyn_hipModuleLoad(&Module, fileName));
|
||||
|
||||
hipFunction_t Function;
|
||||
HIPCHECK(dyn_hipModuleGetFunction(&Function, Module, "bit_extract_kernel"));
|
||||
hipFunction_t Function;
|
||||
HIPCHECK(dyn_hipModuleGetFunction(&Function, Module, "bit_extract_kernel"));
|
||||
|
||||
HIPCHECK(dyn_hipModuleLaunchKernel(Function, 1, 1, 1, LEN, 1, 1, 0, 0, NULL,
|
||||
reinterpret_cast<void**>(&config)));
|
||||
HIPCHECK(dyn_hipModuleLaunchKernel(Function, 1, 1, 1, LEN, 1, 1, 0, 0, NULL,
|
||||
reinterpret_cast<void**>(&config)));
|
||||
|
||||
HIPCHECK(dyn_hipMemcpyDtoH(C_h, (hipDeviceptr_t)(C_d), Nbytes));
|
||||
|
||||
for (size_t i = 0; i < N; i++) {
|
||||
unsigned Agold = ((A_h[i] & 0xf00) >> 8);
|
||||
REQUIRE(C_h[i] == Agold);
|
||||
}
|
||||
HIPCHECK(hipFree(A_d));
|
||||
HIPCHECK(hipFree(C_d));
|
||||
free(A_h);
|
||||
free(C_h);
|
||||
HIPCHECK(dyn_hipMemcpyDtoH(C_h, (hipDeviceptr_t)(C_d), Nbytes));
|
||||
|
||||
for (size_t i = 0; i < N; i++) {
|
||||
unsigned Agold = ((A_h[i] & 0xf00) >> 8);
|
||||
REQUIRE(C_h[i] == Agold);
|
||||
}
|
||||
HIPCHECK(hipFree(A_d));
|
||||
HIPCHECK(hipFree(C_d));
|
||||
free(A_h);
|
||||
free(C_h);
|
||||
}
|
||||
TEST_CASE("Unit_hipApiDynamicLoad_hipGetProcAddress") {
|
||||
void* sym_hipGetDevice;
|
||||
@@ -173,23 +164,21 @@ TEST_CASE("Unit_hipApiDynamicLoad_hipGetProcAddress") {
|
||||
|
||||
int currentHipVersion = 0;
|
||||
HIPCHECK(hipRuntimeGetVersion(¤tHipVersion));
|
||||
|
||||
|
||||
HIPCHECK(hipGetProcAddress("hipGetDevice", &sym_hipGetDevice, currentHipVersion, 0, nullptr));
|
||||
HIPCHECK(hipGetProcAddress("hipMalloc", &sym_hipMalloc, currentHipVersion, 0, nullptr));
|
||||
HIPCHECK(hipGetProcAddress("hipMemcpyHtoD", &sym_hipMemcpyHtoD, currentHipVersion, 0, nullptr));
|
||||
HIPCHECK(hipGetProcAddress("hipMemcpyDtoH", &sym_hipMemcpyDtoH, currentHipVersion, 0, nullptr));
|
||||
HIPCHECK(hipGetProcAddress("hipModuleLoad", &sym_hipModuleLoad, currentHipVersion, 0, nullptr));
|
||||
HIPCHECK(hipGetProcAddress("hipGetDeviceProperties", &sym_hipGetDeviceProperties, currentHipVersion, 0, nullptr));
|
||||
HIPCHECK(hipGetProcAddress("hipModuleGetFunction", &sym_hipModuleGetFunction, currentHipVersion, 0, nullptr));
|
||||
HIPCHECK(hipGetProcAddress("hipModuleLaunchKernel", &sym_hipModuleLaunchKernel, currentHipVersion, 0, nullptr));
|
||||
HIPCHECK(hipGetProcAddress("hipGetDeviceProperties", &sym_hipGetDeviceProperties,
|
||||
currentHipVersion, 0, nullptr));
|
||||
HIPCHECK(hipGetProcAddress("hipModuleGetFunction", &sym_hipModuleGetFunction, currentHipVersion,
|
||||
0, nullptr));
|
||||
HIPCHECK(hipGetProcAddress("hipModuleLaunchKernel", &sym_hipModuleLaunchKernel, currentHipVersion,
|
||||
0, nullptr));
|
||||
|
||||
test_dynamicLoading(sym_hipGetDevice,
|
||||
sym_hipMalloc,
|
||||
sym_hipMemcpyHtoD,
|
||||
sym_hipMemcpyDtoH,
|
||||
sym_hipModuleLoad,
|
||||
sym_hipGetDeviceProperties,
|
||||
sym_hipModuleGetFunction,
|
||||
test_dynamicLoading(sym_hipGetDevice, sym_hipMalloc, sym_hipMemcpyHtoD, sym_hipMemcpyDtoH,
|
||||
sym_hipModuleLoad, sym_hipGetDeviceProperties, sym_hipModuleGetFunction,
|
||||
sym_hipModuleLaunchKernel);
|
||||
}
|
||||
|
||||
@@ -209,17 +198,12 @@ TEST_CASE("Unit_hipApiDynamicLoad") {
|
||||
|
||||
dlclose(handle);
|
||||
|
||||
test_dynamicLoading(sym_hipGetDevice,
|
||||
sym_hipMalloc,
|
||||
sym_hipMemcpyHtoD,
|
||||
sym_hipMemcpyDtoH,
|
||||
sym_hipModuleLoad,
|
||||
sym_hipGetDeviceProperties,
|
||||
sym_hipModuleGetFunction,
|
||||
test_dynamicLoading(sym_hipGetDevice, sym_hipMalloc, sym_hipMemcpyHtoD, sym_hipMemcpyDtoH,
|
||||
sym_hipModuleLoad, sym_hipGetDeviceProperties, sym_hipModuleGetFunction,
|
||||
sym_hipModuleLaunchKernel);
|
||||
}
|
||||
|
||||
/**
|
||||
* End doxygen group DynamicLoading.
|
||||
* @}
|
||||
*/
|
||||
* End doxygen group DynamicLoading.
|
||||
* @}
|
||||
*/
|
||||
|
||||
Referens i nytt ärende
Block a user